@@ -47,9 +47,7 @@ describe 'tripleo::haproxy' do
       it 'should configure haproxy with clustercheck' do
         is_expected.to contain_haproxy__listen('mysql').with(
           :options => {
-            'timeout client' => "90m",
-            'timeout server' => "90m",
-            'option'         => ["tcpka", "httpchk"],
+            'option'         => ["tcpka", "httpchk", "tcplog"],
             'timeout client' => "90m",
             'timeout server' => "90m",
             'stick-table'    => "type ip size 1000",
@@ -71,7 +69,7 @@ describe 'tripleo::haproxy' do
       it 'should configure haproxy' do
         is_expected.to contain_haproxy__listen('mysql').with(
           :options => {
-            'option'         => ["tcpka", "httpchk"],
+            'option'         => ["tcpka", "httpchk", "tcplog"],
             'timeout client' => "90m",
             'timeout server' => "90m",
             'stick-table'    => "type ip size 1000",
@@ -82,6 +80,21 @@ describe 'tripleo::haproxy' do
       end
     end
 
+    describe "horizon" do
+      before :each do
+        params.merge!({
+          :horizon      => true,
+        })
+      end
+
+      it 'should configure haproxy horizon endpoint' do
+        is_expected.to contain_class('tripleo::haproxy::horizon_endpoint')
+        is_expected.to contain_haproxy__balancermember('horizon_127.0.0.1_controller-1').with(
+          :options => ['check', 'inter 2000', 'rise 2', 'fall 5', 'cookie controller-1'],
+        )
+      end
+    end
+
     describe "override maxconn without clustercheck" do
       before :each do
         params.merge!({
